@@ -1,11 +1,11 @@
 /****************************************************************************
-** $Id: qt/qwidget.h   3.3.4   edited Apr 29 2004 $
+** $Id: qt/qwidget.h   3.3.5   edited Aug 31 12:17 $
 **
 ** Definition of QWidget class
 **
 ** Created : 931029
 **
-** Copyright (C) 1992-2003 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
 **
 ** This file is part of the kernel module of the Qt GUI Toolkit.
 **
@@ -49,6 +49,10 @@
 #include "qsizepolicy.h"
 #endif // QT_H
 
+#if defined(Q_WS_X11) && !defined(QT_NO_IM)
+class QInputContext;
+#endif
+
 class QLayout;
 struct QWExtra;
 struct QTLWExtra;
@@ -535,6 +539,18 @@ protected:
 
     int		 metric( int )	const;
 
+#if defined(Q_WS_X11)
+#if !defined(QT_NO_IM_EXTENSIONS)
+    virtual QWidget *icHolderWidget();
+#else
+    QWidget *icHolderWidget();
+#endif
+    QInputContext *getInputContext();
+    void	 changeInputContext( const QString & );
+    void	 sendMouseEventToInputContext( int x, QEvent::Type type,
+					       Qt::ButtonState button,
+					       Qt::ButtonState state );
+#endif
     void	 resetInputContext();
 
     virtual void create( WId = 0, bool initializeWindow = TRUE,
@@ -566,13 +582,16 @@ protected:
 
 private slots:
     void	 focusProxyDestroyed();
+#if defined(Q_WS_X11)
+    void	 destroyInputContext();
+#endif
 
 private:
     void	 setFontSys( QFont *f = 0 );
 #if defined(Q_WS_X11)
     void	 createInputContext();
-    void	 destroyInputContext();
     void	 focusInputContext();
+    void	 unfocusInputContext();
     void	 checkChildrenDnd();
 #elif defined(Q_WS_MAC)
     uint    own_id : 1, macDropEnabled : 1;
@@ -643,6 +662,9 @@ private:
     QFont	 fnt;
 #ifndef QT_NO_LAYOUT
     QLayout 	*lay_out;
+#endif
+#if defined(Q_WS_X11) && !defined(QT_NO_IM) && !defined(QT_NO_IM_EXTENSIONS)
+    QInputContext *ic;				// Input Context
 #endif
     QWExtra	*extra;
 #if defined(Q_WS_QWS)
@@ -949,7 +971,9 @@ struct Q_EXPORT QTLWExtra {
     uint     dnd : 1;				// DND properties installed
     uint     uspos : 1;				// User defined position
     uint     ussize : 1;			// User defined size
-    void    *xic;				// XIM Input Context
+#if defined(QT_NO_IM_EXTENSIONS)
+    void    *xic;				// Input Context
+#endif
 #endif
 #if defined(Q_WS_MAC)
     WindowGroupRef group;
